SET PAGESIZE 0
SET LINESIZE 32767
SET TRIMSPOOL ON
SET TERMOUT OFF
SET FEEDBACK OFF
SET HEADING ON
SET ECHO OFF
SET COLSEP ';'
SET LONG 2000000000
SET LONGCHUNKSIZE 32767

SPOOL reltext.csv

SELECT * FROM INFOR.RELTEXT;

SPOOL OFF
EXIT